# Work out the set of components to load
if(${CMAKE_FIND_PACKAGE_NAME}_FIND_COMPONENTS)
	set(comps ${${CMAKE_FIND_PACKAGE_NAME}_FIND_COMPONENTS})
	# Ensure <package>_Runtime is included if <package>_Development was specified
	if(${CMAKE_FIND_PACKAGE_NAME}_Development IN_LIST comps AND
		NOT ${CMAKE_FIND_PACKAGE_NAME}_Runtime IN_LIST comps)
			list(APPEND comps ${CMAKE_FIND_PACKAGE_NAME}_Runtime)
	endif()
else()
	# No components given, look for all components
	set(comps ${CMAKE_FIND_PACKAGE_NAME}_Runtime ${CMAKE_FIND_PACKAGE_NAME}_Development)
endif()

# Check for dependency
if(${CMAKE_HOST_SYSTEM_NAME} STREQUAL "Linux")
	unset(extraArgs)
	if(${CMAKE_FIND_PACKAGE_NAME}_FIND_QUIETLY)
		list(APPEND extraArgs QUIET)
	endif()
	if(${CMAKE_FIND_PACKAGE_NAME}_FIND_REQUIRED)
		list(APPEND extraArgs REQUIRED)
	endif()
	find_package(CURL REQUIRED)
	if(NOT CURL_FOUND)
		set(${CMAKE_FIND_PACKAGE_NAME}_NOT_FOUND_MESSAGE "Missing dependency: CURL")
		set(${CMAKE_FIND_PACKAGE_NAME}_FOUND FALSE)
		return()
	endif()
endif()

# Check all required components are available before trying to load any
set(${CMAKE_FIND_PACKAGE_NAME}_comps ${comps})
foreach(comp IN LISTS ${CMAKE_FIND_PACKAGE_NAME}_comps)
	string(REPLACE "_" "-" comp_file_name ${comp})
	string(TOLOWER ${comp_file_name} comp_file_name)
	if(${CMAKE_FIND_PACKAGE_NAME}_FIND_REQUIRED_${comp} AND
		NOT EXISTS ${CMAKE_CURRENT_LIST_DIR}/${comp_file_name}-config.cmake)
			set(${CMAKE_FIND_PACKAGE_NAME}_NOT_FOUND_MESSAGE
				"${CMAKE_FIND_PACKAGE_NAME} missing required component: ${comp}"
			)
			set(${CMAKE_FIND_PACKAGE_NAME}_FOUND FALSE)
			return()
	endif()
endforeach()

# Load the components
foreach(comp IN LISTS ${CMAKE_FIND_PACKAGE_NAME}_comps)
	string(REPLACE "_" "-" comp_file_name ${comp})
	string(TOLOWER ${comp_file_name} comp_file_name)
	include(${CMAKE_CURRENT_LIST_DIR}/${comp_file_name}-config.cmake OPTIONAL)
endforeach()